Skip to contents

Represents models based on ALBERT

Value

Does return a new object of this class.

References

Lan, Z., Chen, M., Goodman, S., Gimpel, K., Sharma, P., & Soricut, R. (2019). ALBERT; A Lite BERT for Self-supervised Learning of Language Representations. arXiv. doi:10.48550/ARXIV.1909.11942

Super classes

AIFEMaster -> AIFEBaseModel -> BaseModelCore -> BaseModelAlbert

Methods

Inherited methods


BaseModelAlbert$configure()

Configures a new object of this class. Please ensure that your chosen configuration comply with the following guidelines:

  • hidden_size is a multiple of num_attention_heads.

Usage

BaseModelAlbert$configure(
  tokenizer,
  max_position_embeddings = 512L,
  hidden_size = 768L,
  embedding_size = 128L,
  num_hidden_layers = 12L,
  num_hidden_groups = 1L,
  num_attention_heads = 12L,
  intermediate_size = 3072L,
  hidden_act = "GELU",
  hidden_dropout_prob = 0.1,
  attention_probs_dropout_prob = 0.1
)

Arguments

tokenizer

TokenizerBase Tokenizer for the model.

max_position_embeddings

int Number of maximum position embeddings. This parameter also determines the maximum length of a sequence which can be processed with the model. Allowed values:

\(10 <= x <= 4048\)

hidden_size

int Number of neurons in each layer. This parameter determines the dimensionality of the resulting text embedding. Allowed values:

\(1 <= x <= 2048\)

embedding_size

int Dimensionality of the token embeddings. Allowed values:

\(1 <= x \)

num_hidden_layers

int Number of hidden layers. Allowed values:

\(1 <= x \)

num_hidden_groups

int Number of groups for the hidden layers. Layers belonging to the same group share parameters. Allowed values:

\(1 <= x \)

num_attention_heads

int determining the number of attention heads for a self-attention layer. Only relevant if attention_type='MultiHead' Allowed values:

\(0 <= x \)

intermediate_size

int determining the size of the projection layer within a each transformer encoder. Allowed values:

\(1 <= x \)

hidden_act

string Name of the activation function. Allowed values:

  • 'GELU'

  • 'relu'

  • 'silu'

  • 'gelu_new'

hidden_dropout_prob

double Ratio of dropout. Allowed values:

\(0 <= x <= 0.6\)

attention_probs_dropout_prob

double Ratio of dropout for attention probabilities. Allowed values:

\(0 <= x <= 0.6\)

Returns

Does nothing return.


BaseModelAlbert$clone()

The objects of this class are cloneable with this method.

Usage

BaseModelAlbert$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.