Skip to contents

Represents models based on EuroBERT.

Value

Does return a new object of this class.

References

Boizard, N., Gisserot-Boukhlef, H., Alves, D. M., Martins, A., Hammal, A., Corro, C., Hudelot, C., Malherbe, E., Malaboeuf, E., Jourdan, F., Hautreux, G., Alves, J., El-Haddad, K., Faysse, M., Peyrard, M., Guerreiro, N. M., Fernandes, P., Rei, R. & Colombo, P. (2025). EuroBERT: Scaling Multilingual Encoders for European Languages. doi:10.48550/arXiv.2503.05500

Super classes

AIFEMaster -> AIFEBaseModel -> BaseModelCore -> BaseModelEuroBert

Methods

Inherited methods


BaseModelEuroBert$configure()

Configures a new object of this class. Please ensure that your chosen configuration comply with the following guidelines:

  • hidden_size is a multiple of num_attention_heads.

Usage

BaseModelEuroBert$configure(
  tokenizer,
  max_position_embeddings = 512L,
  hidden_size = 768L,
  num_hidden_layers = 12L,
  num_attention_heads = 12L,
  intermediate_size = 3072L,
  hidden_act = "GELU",
  attention_dropout = 0.1
)

Arguments

tokenizer

TokenizerBase Tokenizer for the model.

max_position_embeddings

int Number of maximum position embeddings. This parameter also determines the maximum length of a sequence which can be processed with the model. Allowed values:

\(10 <= x <= 4048\)

hidden_size

int Number of neurons in each layer. This parameter determines the dimensionality of the resulting text embedding. Allowed values:

\(1 <= x <= 2048\)

num_hidden_layers

int Number of hidden layers. Allowed values:

\(1 <= x \)

num_attention_heads

int determining the number of attention heads for a self-attention layer. Only relevant if attention_type='MultiHead' Allowed values:

\(0 <= x \)

intermediate_size

int determining the size of the projection layer within a each transformer encoder. Allowed values:

\(1 <= x \)

hidden_act

string Name of the activation function. Allowed values:

  • 'GELU'

  • 'relu'

  • 'silu'

  • 'gelu_new'

attention_dropout

double Ratio of dropout for attention probabilities. Allowed values:

\(0 <= x <= 0.6\)

attention_probs_dropout_prob

double Ratio of dropout for attention probabilities. Allowed values:

\(0 <= x <= 0.6\)

Returns

Does nothing return.


BaseModelEuroBert$clone()

The objects of this class are cloneable with this method.

Usage

BaseModelEuroBert$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.