Skip to contents

Function for generating the whole documentation for an article used on the package's home page.

Usage

build_layer_overview_base_models()

Value

Returns a string containing the description written in rmarkdown.

Note

Function is designed to be used with inline r code in rmarkdown vignettes/articles.