Skip to contents

Depending on the test environment, the function adjusts the number of samples. For continuous integration, it is limited to a random sample of combinations. The same applies if CUDA is unavailable.

Usage

check_adjust_n_samples_on_CI(n_samples_requested, n_CI = 50L)

Arguments

n_samples_requested

int Number of samples if the test do not run on continuous integration.

n_CI

int Number of samples if the test run on continuous integration.

Value

Returns an int depending on the test environment.