Check if all necessary python modules are available
Source:R/install_and_config.R
check_aif_py_modules.RdThis function checks if all python modules necessary for the package 'aifeducation' to work are available.
Value
The function prints a table with all relevant packages and shows which modules are available or unavailable.
If all relevant modules are available, the functions returns TRUE. In all other cases it returns FALSE