Function for preparing and cleaning the log created by an object of class Trainer from the python library 'transformer's
clean_pytorch_log_transformers(log)Returns a data.frame containing epochs, loss, and val_loss.
data.frame containing the log.
Other Auxiliary Functions:
array_to_matrix(),
calc_standard_classification_measures(),
check_embedding_models(),
create_iota2_mean_object(),
create_synthetic_units(),
generate_id(),
get_coder_metrics(),
get_folds(),
get_n_chunks(),
get_stratified_train_test_split(),
get_synthetic_cases(),
get_train_test_split(),
is.null_or_na(),
matrix_to_array_c(),
split_labeled_unlabeled(),
summarize_tracked_sustainability(),
to_categorical_c()