Skip to contents

Function creates a valid file path for the argument cache_file_name of classes "datasets.arrow_dataset.Dataset" from the python library 'datasets'. The aim of the function is to ensure compatibility between different versions of 'datasets'.

Usage

create_py_dataset_cache_file_path(file_path)

Arguments

file_path

string file path without file extension.

Value

Returns a file path as string.