Functions prints the used arguments. The aim of this function is to print the arguments to the console that resulted in a failed test.
Arguments
- arg_list
Named
listof arguments. The list should be generated with generate_args_for_tests.
Functions prints the used arguments. The aim of this function is to print the arguments to the console that resulted in a failed test.
Named list of arguments. The list should be generated with generate_args_for_tests.