Function for receiving a list containing a description of all core models
user of the package can apply.
Usage
get_dict_core_models(model)
Arguments
- model
string Name of the model that should be returned. If model="all"
all models are returned as a list.
Value
Returns a list with the following entries:
title: string Name of the model.
desc: stringDescription of the model written in rmarkdown.
img: string Name of the image used to illustrate the model. File extension must be '.png'.