R/def_DocumentationDesc.R
get_dict_input_types.Rd
Function for receiving a list containing a description of the input types necessary for specific models.
list
get_dict_input_types(input_type)
string Input type
string
Returns a string containing the description of the required input written in rmarkdown.
Other Utils Documentation: build_documentation_for_model(), build_layer_stack_documentation_for_vignette(), get_desc_for_core_model_architecture(), get_dict_cls_type(), get_dict_core_models(), get_layer_dict(), get_layer_documentation(), get_parameter_documentation()
build_documentation_for_model()
build_layer_stack_documentation_for_vignette()
get_desc_for_core_model_architecture()
get_dict_cls_type()
get_dict_core_models()
get_layer_dict()
get_layer_documentation()
get_parameter_documentation()