Function generates a static test tensor which is always the same.
Usage
get_fixed_test_tensor(pad_value)
Arguments
- pad_value
int Value used to indicate padding.
Value
Returns an object of class Tensor which is always the same except padding.
Shape (5,3,7).