Function for receiving a list containing a description of all layers
user of the package can apply.
Value
Returns a list with the following entries:
title:
stringName of the layer.desc:
stringDescription of the layer written in rmarkdown.img:
stringName of the image used to illustrate the layer. File extension must be '.png'.references:
vectorofstrings. Every entry contains the literature reference in rmarkdown if relevant.param_prefix:
stringPrefix used for all parameters to configure the specific layer.