Function for generating the documentation of a specific layer.
Usage
get_parameter_documentation(
param_name,
param_dict,
as_list = TRUE,
inc_param_name = TRUE
)
Arguments
- param_name
string Name of the parameter.
- param_dict
list storing the parameter description.
- as_list
bool If TRUE returns the element as part of a list.
- inc_param_name
bool If TRUE the documentation includes the name of the parameter.
Value
Returns a string containing the description written in rmarkdown.