Skip to contents

Function for requesting a summary of the versions of all critical python components.

Usage

get_py_package_versions(sentencepiece = FALSE)

Arguments

sentencepiece

bool If TRUE the packages 'google.protobuf' and 'sentencepiece' are checked.

Value

Returns a list that contains the version number of python and the versions of critical python packages. If a package is not available version is set to NA.