Skip to contents

Returns the minimum and maximum versions of the core python packages used in aifeducation. It is recommended to use packages of these version. Packages of other versions can result in errors or unexpected results.

Usage

get_recommended_py_versions(package_name = NULL)

Arguments

package_name

string Name of the package the recommended version should be returned. If set to NULL a table with all core packages and their supported version is returned.

Value

Returns a data.frame with the packages in the columns and the minimum, maximum, and recommended version in the rows. If a concrete name is passed returns a string with leading '<='.