R/utils_general.R
get_time_stamp.Rd
Function returns the time on the machine at the moment of calling.
get_time_stamp()
Returns a string with date and time in format "%y-%m-%d %H:%M:%S".
string
Other Utils Developers: auto_n_cores(), create_object(), create_synthetic_units_from_matrix(), generate_id(), get_n_chunks(), get_synthetic_cases_from_matrix(), matrix_to_array_c(), tensor_to_matrix_c(), to_categorical_c()
auto_n_cores()
create_object()
create_synthetic_units_from_matrix()
generate_id()
get_n_chunks()
get_synthetic_cases_from_matrix()
matrix_to_array_c()
tensor_to_matrix_c()
to_categorical_c()