Skip to contents

This function is a support function to install the protocol buffer compiler which is necessary for using the python libraries 'protobuf' and 'sentencepiece'. Details can be found here https://protobuf.dev/installation/.

On Windows the function uses Winget requiring Windows 10 or higher. On MacOS it uses Homebrew. On Linux it uses apt.

Usage

install_protocol_buffer_compiler()

Value

This function does not return anything. It installs the protocol buffer compiler