R/RcppExports.R
matrix_to_array_c.Rd
Function written in C++ for reshaping a matrix containing sequential data into an array for use with keras.
matrix_to_array_c(matrix, times, features)
matrix containing the sequential data.
matrix
uword Number of sequences.
uword
uword Number of features within each sequence.
Returns an array. The first dimension corresponds to the cases, the second to the times, and the third to the features.
Other Utils Developers: auto_n_cores(), create_object(), create_synthetic_units_from_matrix(), generate_id(), get_n_chunks(), get_synthetic_cases_from_matrix(), get_time_stamp(), tensor_to_matrix_c(), to_categorical_c()
auto_n_cores()
create_object()
create_synthetic_units_from_matrix()
generate_id()
get_n_chunks()
get_synthetic_cases_from_matrix()
get_time_stamp()
tensor_to_matrix_c()
to_categorical_c()