prepare_r_array_for_dataset: Convert R array for arrow data set

View source: R/utils_python_data_management.R

prepare_r_array_for_datasetR Documentation

Convert R array for arrow data set

Description

Function converts a R array into a numpy array that can be added to an arrow data set. The array should represent embeddings.

Usage

prepare_r_array_for_dataset(r_array)

Arguments

r_array

array representing embeddings.

Value

Returns a numpy array.

See Also

Other Utils Python Data Management Developers: class_vector_to_py_dataset(), create_py_dataset_cache_file_path(), data.frame_to_py_dataset(), extract_column_from_py_dataset(), get_batches_index(), py_dataset_to_embeddings(), reduce_to_unique(), tensor_list_to_numpy(), tensor_to_numpy()


aifeducation documentation built on March 3, 2026, 1:06 a.m.