py_dataset_to_embeddings: Convert arrow data set to an arrow data set

View source: R/utils_python_data_management.R

py_dataset_to_embeddingsR Documentation

Convert arrow data set to an arrow data set

Description

Function for converting an arrow data set into a data set that can be used to store and process embeddings.

Usage

py_dataset_to_embeddings(py_dataset)

Arguments

py_dataset

Object of class datasets.arrow_dataset.Dataset.

Value

Returns the data set of class datasets.arrow_dataset.Dataset with only two columns ("id","input"). "id" stores the name of the cases while "input" stores the embeddings.

See Also

Other Utils Python Data Management Developers: class_vector_to_py_dataset(), create_py_dataset_cache_file_path(), data.frame_to_py_dataset(), extract_column_from_py_dataset(), get_batches_index(), prepare_r_array_for_dataset(), reduce_to_unique(), tensor_list_to_numpy(), tensor_to_numpy()


aifeducation documentation built on March 3, 2026, 1:06 a.m.