Skip to contents

This function changes the level for logging information of the 'codecarbon' library.

Usage

set_codecarbon_logger(level = "ERROR")

Arguments

level

string Minimal level that should be printed to console. Four levels are available: "INFO", "WARNING", "ERROR", "CRITICAL", and "DEBUG"

Value

This function does not return anything. It is used for its side effects.