This function changes the level for logging information with 'tensorflow'.
set_config_tf_logger(level = "ERROR")This function does not return anything. It is used for its side effects.
string Minimal level that should be printed to console. Five
levels are available: FATAL, ERROR, WARN, INFO, and DEBUG.
Other Installation and Configuration:
AifeducationConfiguration,
aifeducation_config,
check_aif_py_modules(),
install_py_modules(),
set_config_cpu_only(),
set_config_gpu_low_memory(),
set_config_os_environ_logger(),
set_transformers_logger()