Function for summarizing the tracked sustainability data with a tracker of the python library 'codecarbon'.
summarize_tracked_sustainability(sustainability_tracker)Returns a list which contains the tracked sustainability data.
Object of class codecarbon.emissions_tracker.OfflineEmissionsTracker
of the python library codecarbon.
Other Auxiliary Functions:
array_to_matrix(),
calc_standard_classification_measures(),
check_embedding_models(),
clean_pytorch_log_transformers(),
create_iota2_mean_object(),
create_synthetic_units(),
generate_id(),
get_coder_metrics(),
get_folds(),
get_n_chunks(),
get_stratified_train_test_split(),
get_synthetic_cases(),
get_train_test_split(),
is.null_or_na(),
matrix_to_array_c(),
split_labeled_unlabeled(),
to_categorical_c()