Skip to contents

Objects of this class containing fields and methods used in several other classes in 'AI for Education'.

This class is not designed for a direct application and should only be used by developers.

Value

A new object of this class.

Super class

AIFEMaster -> AIFEBaseModel

Methods

Inherited methods


AIFEBaseModel$count_parameter()

Method for counting the trainable parameters of a model.

Usage

AIFEBaseModel$count_parameter()

Returns

Returns the number of trainable parameters of the model.


AIFEBaseModel$clone()

The objects of this class are cloneable with this method.

Usage

AIFEBaseModel$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.