Objects of this class containing fields and methods used in several other classes in 'AI for Education'.
This class is not designed for a direct application and should only be used by developers.
See also
Other R6 Classes for Developers:
AIFEBaseModel,
BaseModelCore,
ClassifiersBasedOnTextEmbeddings,
DataManagerClassifier,
LargeDataSetBase,
ModelsBasedOnTextEmbeddings,
TEClassifiersBasedOnProtoNet,
TEClassifiersBasedOnRegular,
TokenizerBase
Public fields
last_training('list()')
List for storing the history, the configuration, and the results of the last training. This information will be overwritten if a new training is started.last_training$start_time: Time point when training started.last_training$learning_time: Duration of the training process.last_training$finish_time: Time when the last training finished.last_training$history: History of the last training.last_training$data: Object of classtablestoring the initial frequencies of the passed data.last_training$config: List storing the configuration used for the last training.
Methods
AIFEMaster$set_publication_info()
Method for setting publication information of the model.
AIFEMaster$set_model_description()
Method for setting a description of the model.
Usage
AIFEMaster$set_model_description(
eng = NULL,
native = NULL,
abstract_eng = NULL,
abstract_native = NULL,
keywords_eng = NULL,
keywords_native = NULL
)Arguments
engstringA text describing the training, its theoretical and empirical background, and output in English.nativestringA text describing the training , its theoretical and empirical background, and output in the native language of the model.abstract_engstringA text providing a summary of the description in English.abstract_nativestringA text providing a summary of the description in the native language of the model.keywords_engvectorof keyword in English.keywords_nativevectorof keyword in the native language of the model.
AIFEMaster$get_package_versions()
Method for requesting a summary of the R and python packages' versions used for creating the model.
AIFEMaster$get_sustainability_data()
Method for requesting a summary of tracked energy consumption during training and an estimate of the resulting CO2 equivalents in kg.
AIFEMaster$get_ml_framework()
Method for requesting the machine learning framework used for the model.
AIFEMaster$is_configured()
Method for checking if the model was successfully configured. An object can only be used if this
value is TRUE.
AIFEMaster$is_trained()
Check if the TEFeatureExtractor is trained.
AIFEMaster$get_private()
Method for requesting all private fields and methods. Used for loading and updating an object.