Set sample size for argument combinations
Source:R/utils_test_that.R
check_adjust_n_samples_on_CI.RdDepending on the test environment, the function adjusts the number of samples. For continuous integration, it is limited to a random sample of combinations. The same applies if CUDA is unavailable.