Set sample size for argument combinations
Source:R/utils_test_that.R
check_adjust_n_samples_on_CI.RdFunction adjust the number of samples depending on the test environment. On continuous integration it is limited to a random sample of combinations.