create_py_dataset_cache_file_path: File path for caching data sets

View source: R/utils_python_data_management.R

create_py_dataset_cache_file_pathR Documentation

File path for caching data sets

Description

Function creates a valid file path for the argument cache_file_name of classes "datasets.arrow_dataset.Dataset" from the python library 'datasets'. The aim of the function is to ensure compatibility between different versions of 'datasets'.

Usage

create_py_dataset_cache_file_path(file_path)

Arguments

file_path

string file path without file extension.

Value

Returns a file path as string.

See Also

Other Utils Python Data Management Developers: class_vector_to_py_dataset(), data.frame_to_py_dataset(), extract_column_from_py_dataset(), get_batches_index(), prepare_r_array_for_dataset(), py_dataset_to_embeddings(), reduce_to_unique(), tensor_list_to_numpy(), tensor_to_numpy()


aifeducation documentation built on March 3, 2026, 1:06 a.m.