Function extracts the content of a column from a python data set in order to allow further operations in R.
Value
Returns a vector, matrix or array for format="R". In all other
cases the requested format is returned.
See also
Other Utils Python Data Management Developers:
class_vector_to_py_dataset(),
create_py_dataset_cache_file_path(),
data.frame_to_py_dataset(),
get_batches_index(),
prepare_r_array_for_dataset(),
py_dataset_to_embeddings(),
reduce_to_unique(),
tensor_list_to_numpy(),
tensor_to_numpy()