extract_column_from_py_dataset: Extract column

View source: R/utils_python_data_management.R

extract_column_from_py_datasetR Documentation

Extract column

Description

Function extracts the content of a column from a python data set in order to allow further operations in R.

Usage

extract_column_from_py_dataset(py_dataset, column_name, format = "R")

Arguments

py_dataset

datasets.arrow_dataset.Dataset data set to extract the column from.

column_name

string Name of the column to extract.

format

string Format of the requested data.

  • "R" returns the data as a R object.

  • "torch" returns the data as PyTorch tensors.

  • "numpy" returns the data as numpy array.

Value

Returns a vector, matrix or array for format="R". In all other cases the requested format is returned.

See Also

Other Utils Python Data Management Developers: class_vector_to_py_dataset(), create_py_dataset_cache_file_path(), data.frame_to_py_dataset(), get_batches_index(), prepare_r_array_for_dataset(), py_dataset_to_embeddings(), reduce_to_unique(), tensor_list_to_numpy(), tensor_to_numpy()


aifeducation documentation built on March 3, 2026, 1:06 a.m.