Function generates a specific number of combinations for a method. These are used for automating tests of objects.
Arguments
- object_name
stringName of the object to generate the arguments for.- method
stringName of the method of the object to generate the arguments for.- var_objects
listof other objects which should be combined with the other arguments.- necessary_objects
listof other objects which are part of every combination.- var_override
Named
listcontaining the arguments which should be set to a specific value for all combinations.
Note
var_objects, necessary_objects, and var_override the names must exactly match
the name of the parameter. Otherwise they are not applied. Names of arguments which are not part
a a method are ignored. #'