Functions generates a random test tensor that can be used for testing methods and functions based on 'PyTorch'. The tensors have the shape (Batch, Times,Features).
Arguments
- times
intMaximal length of a sequence.- features
intNumber of features of the sequence.- seq_len
Numeric
vectorcontaining the length of the given cases. The length of this vector determines the value for 'Batch'. Values must be at least 1 and maximaltimes.- pad_value
intValue used to indicate padding.
Note
To request a R array please use generate_embeddings.