Function for calculating the number of chunks/sequences for every case.
Arguments
- text_embeddings
data.frameorarraycontaining the text embeddings.- features
intNumber of features within each sequence.- times
intNumber of sequences.- pad_value
intValue indicating padding. This value should no be in the range of regluar values for computations. Thus it is not recommended to chance this value. Default is-100. Allowed values: \( x <= -1\)