Function for setting up a python environment within R.
Source:R/install_and_config.R
prepare_session.RdThis functions checks for python and a specified environment. If the environment exists it will be activated. If python is already initialized it uses the current environment.
Arguments
- env_type
stringIf set to"venv"virtual environment is requested. If set to"conda"a 'conda' environment is requested. If set to"auto"the function tries to activate a virtual environment with the given name. If this environment does not exist it tries to activate a conda environment with the given name. If this fails the default virtual environment is used.- envname
stringenvname name of the requested environment.- check_session
boolIfTRUEfunctions checks if all necessary python packages are available. Set this argument toFALSEcan speed up sessions' preparation. Set this argument toFALSEonly if you are certain that the requirements for the package are satisfied.
See also
Other Installation and Configuration:
check_aif_py_modules(),
get_recommended_py_versions(),
install_aifeducation(),
install_aifeducation_studio(),
install_py_modules(),
set_transformers_logger(),
update_aifeducation()