Sets the level for logging information of the 'codecarbon' library
Source:R/install_and_config.R
set_codecarbon_logger.RdThis function changes the level for logging information of the 'codecarbon' library.
R/install_and_config.R
set_codecarbon_logger.RdThis function changes the level for logging information of the 'codecarbon' library.